@@ -24,6 +24,7 @@ from pyipmi.msgs import create_request_by_name
 from pyipmi.msgs import constants
 
 from pyipmi.helper import get_sdr_data_helper, clear_repository_helper
+from pyipmi.helper import get_sdr_chunk_helper
 from pyipmi.state import State
 
 SDR_TYPE_FULL_SENSOR_RECORD = 0x01
@@ -38,9 +39,23 @@ SDR_TYPE_BMC_MESSAGE_CHANNEL_INFO_RECORD = 0x14
 GET_INITIALIZATION_AGENT_STATUS = 0
 RUN_INITIALIZATION_AGENT = 1
 
+L_LINEAR = 0
+L_LN = 1
+L_LOG = 2
+L_LOG2 = 3
+L_E = 4
+L_EXP10 = 5
+L_EXP2 = 6
+L_1_X = 7
+L_SQR = 8
+L_CUBE = 9
+L_SQRT = 10
+L_CUBERT = 11
+
 class Sdr(object):
     def get_sdr_repository_info(self):
-        return SdrRepositoryInfo(self.send_message_with_name('GetSdrRepositoryInfo'))
+        return SdrRepositoryInfo(
+                self.send_message_with_name('GetSdrRepositoryInfo'))
 
     def get_sdr_repository_allocation_info(self):
         return SdrRepositoryAllocationInfo(
@@ -56,35 +71,17 @@ class Sdr(object):
         req.record_id = record_id
         req.offset = offset
         req.bytes_to_read = length
-        retry = 5
 
-        while True:
-            retry -= 1
-            if retry == 0:
-                raise RetryError()
-            rsp = self.send_message(req)
-            if rsp.completion_code == constants.CC_OK:
-                break
-            elif rsp.completion_code == constants.CC_RES_CANCELED:
-                req.reservation_id = self.reserve_sdr_repository()
-                time.sleep(0.1)
-                continue
-            elif rsp.completion_code == constants.CC_TIMEOUT:
-                time.sleep(0.1)
-                continue
-            elif rsp.completion_code == constants.CC_RESP_COULD_NOT_BE_PRV:
-                time.sleep(0.1 * retry)
-                continue
-            else:
-                check_completion_code(rsp.completion_code)
+        rsp = get_sdr_chunk_helper(self.send_message, req, \
+                self.reserve_device_sdr_repository)
 
-        return (rsp.next_record_id, rsp.data)
+        return (rsp.next_record_id, rsp.record_data)
 
     def get_repository_sdr(self, record_id, reservation_id=None):
         (next_id, record_data) = get_sdr_data_helper(
                 self.reserve_sdr_repository, self._get_sdr_chunk,
                 record_id, reservation_id)
-        return create_sdr(record_data, next_id)
+        return SdrCommon.from_data(record_data, next_id)
 
     def sdr_repository_entries(self):
         """A generator that returns the SDR list. Starting with ID=0x0000 and
@@ -121,21 +118,14 @@ class Sdr(object):
     def delete_sdr(self, record_id):
         """Deletes the sensor record specified by 'record_id'.
         """
-
         reservation_id = self.reserve_device_sdr_repository()
-        req = create_request_by_name('DeleteSdr')
-        req.reservation_id = reservation_id
-        req.record_id = record_id
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        rsp = self.send_message_with_name('DeleteSdr',
+                reservation_id=reservation_id, record_id=record_id)
         return rsp.record_id
 
     def _clear_sdr_repository(self, cmd, reservation_id):
-        req = create_request_by_name('ClearSdrRepository')
-        req.reservation_id = reservation_id
-        req.cmd = cmd
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        rsp = self.send_message_with_name('ClearSdrRepository',
+                reservation_id=reservation_id, cmd=cmd)
         return rsp.status.erase_in_progress
 
     def clear_sdr_repository(self, retry=5):
@@ -143,10 +133,7 @@ class Sdr(object):
                 self._clear_sdr_repository, retry)
 
     def _run_initialization_agent(self, cmd):
-        req = create_request_by_name('RunInitializationAgent')
-        req.cmd = cmd
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        rsp = self.send_message_with_name('RunInitializationAgent', cmd=cmd)
         return rsp.status.initialization_completed
 
     def start_initialization_agent(self):
@@ -155,8 +142,8 @@ class Sdr(object):
     def get_initialization_agent_status(self):
         return self._run_initialization_agent(GET_INITIALIZATION_AGENT_STATUS)
 
-class SdrRepositoryInfo(State):
 
+class SdrRepositoryInfo(State):
     def _from_response(self, rsp):
         self.sdr_version = rsp.sdr_version
         self.record_count = rsp.record_count
@@ -169,8 +156,8 @@ class SdrRepositoryInfo(State):
         self.support_update_type = rsp.support.update_type
         self.support_overflow_flag = rsp.support.overflow_flag
 
-class SdrRepositoryAllocationInfo(State):
 
+class SdrRepositoryAllocationInfo(State):
     def _from_response(self, rsp):
         self.number_of_units = rsp.number_of_units
         self.unit_size = rsp.unit_size
@@ -179,31 +166,15 @@ class SdrRepositoryAllocationInfo(State):
         self.maximum_record_size = rsp.maximum_record_size
 
 
-def create_sdr(data, next_id=None):
-    sdr_type = data[3]
-
-    if sdr_type == SDR_TYPE_FULL_SENSOR_RECORD:
-        return SdrFullSensorRecord(data, next_id)
-    elif sdr_type == SDR_TYPE_COMPACT_SENSOR_RECORD:
-        return SdrCompactSensorRecord(data, next_id)
-    elif sdr_type == SDR_TYPE_EVENT_ONLY_SENSOR_RECORD:
-        return SdrEventOnlySensorRecord(data, next_id)
-    elif sdr_type == SDR_TYPE_FRU_DEVICE_LOCATOR_RECORD:
-        return SdrFruDeviceLocator(data, next_id)
-    elif sdr_type == SDR_TYPE_MANAGEMENT_CONTROLLER_DEVICE_LOCATOR_RECORD:
-        return SdrManagementContollerDeviceLocator(data, next_id)
-    elif sdr_type == SDR_TYPE_MANAGEMENT_CONTROLLER_CONFIRMATION_RECORD:
-        raise DecodingError('Unsupported SDR type(0x%02x)' % sdr_type)
-    elif sdr_type == SDR_TYPE_BMC_MESSAGE_CHANNEL_INFO_RECORD:
-        raise DecodingError('Unsupported SDR type(0x%02x)' % sdr_type)
-    else:
-        raise DecodingError('Unsupported SDR type(0x%02x)' % sdr_type)
-
-
 class SdrCommon(object):
     def __init__(self, data, next_id=None):
         if data:
-            self._from_response(data)
+            self.data = data
+            self._common_header(data)
+
+            if hasattr(self, '_from_data'):
+                self._from_data(data)
+
         if next_id:
             self.next_id = next_id
 
@@ -212,16 +183,47 @@ class SdrCommon(object):
             (self.device_id_string, ' '.join(['%02x' % b for b in self.data]))
         return s
 
-    def _from_response(self, data):
-        if len(data) < 5:
+    def _common_header(self, data):
+        buffer = ByteBuffer(data[:])
+        try:
+            self.id = buffer.pop_unsigned_int(2)
+            self.version = buffer.pop_unsigned_int(1)
+            self.type = buffer.pop_unsigned_int(1)
+            self.length = buffer.pop_unsigned_int(1)
+        except:
             raise DecodingError('Invalid SDR length (%d)' % len(data))
 
-        self.data = data
-        buffer = ByteBuffer(data[:])
-        self.id = buffer.pop_unsigned_int(2)
-        self.version = buffer.pop_unsigned_int(1)
-        self.type = buffer.pop_unsigned_int(1)
-        self.length = buffer.pop_unsigned_int(1)
+    def _common_record_key(self, buffer):
+        self.owner_id = buffer.pop_unsigned_int(1)
+        self.owner_lun = buffer.pop_unsigned_int(1) & 0x3
+        self.number = buffer.pop_unsigned_int(1)
+
+    def _entity(self, buffer):
+        self.entity_id = buffer.pop_unsigned_int(1)
+        self.entity_instance = buffer.pop_unsigned_int(1)
+
+    @staticmethod
+    def from_data(data, next_id=None):
+        sdr_type = data[3]
+
+        try:
+            cls = {
+                SDR_TYPE_FULL_SENSOR_RECORD:
+                        SdrFullSensorRecord,
+                SDR_TYPE_COMPACT_SENSOR_RECORD:
+                        SdrCompactSensorRecord,
+                SDR_TYPE_EVENT_ONLY_SENSOR_RECORD:
+                        SdrEventOnlySensorRecord,
+                SDR_TYPE_FRU_DEVICE_LOCATOR_RECORD:
+                        SdrFruDeviceLocator,
+                SDR_TYPE_MANAGEMENT_CONTROLLER_DEVICE_LOCATOR_RECORD:
+                        SdrManagementContollerDeviceLocator,
+            }[sdr_type]
+        except KeyError:
+            raise DecodingError('Unsupported SDR type(0x%02x)' % sdr_type)
+
+        return cls(data, next_id)
+
 
 ###
 # SDR type 0x01
@@ -232,24 +234,6 @@ class SdrFullSensorRecord(SdrCommon):
     DATA_FMT_2S_COMPLEMENT = 2
     DATA_FMT_NONE = 3
 
-    L_LINEAR = 0
-    L_LN = 1
-    L_LOG = 2
-    L_LOG2 = 3
-    L_E = 4
-    L_EXP10 = 5
-    L_EXP2 = 6
-    L_1_X = 7
-    L_SQR = 8
-    L_CUBE = 9
-    L_SQRT = 10
-    L_CUBERT = 11
-
-    def __init__(self, data, next_id=None):
-        SdrCommon.__init__(self, data, next_id)
-        if data:
-            self._from_data(data)
-
     def convert_sensor_raw_to_value(self, raw):
         fmt = self.analog_data_format
         if (fmt == self.DATA_FMT_1S_COMPLEMENT):
@@ -265,7 +249,7 @@ class SdrFullSensorRecord(SdrCommon):
     def convert_sensor_value_to_raw(self, value):
         linearization = self.linearization & 0x7f
 
-        if linearization is not self.L_LINEAR:
+        if linearization is not L_LINEAR:
             raise NotImplementedError()
 
         raw = ((float(value) * 10**(-1 * self.k2)) / self.m) - (self.b * 10**self.k1)
@@ -286,35 +270,24 @@ class SdrFullSensorRecord(SdrCommon):
 
     @property
     def l(self):
-        linearization = self.linearization & 0x7f
-        if linearization == self.L_LN:
-            l = math.log
-        elif linearization == self.L_LOG:
-            l = lambda x: math.log(x, 10)
-        elif linearization == self.L_LOG2:
-            l = lambda x: math.log(x, 2)
-        elif linearization == self.L_E:
-            l = math.exp
-        elif linearization == self.L_EXP10:
-            l = lambda x: math.pow(10, x)
-        elif linearization == self.L_EXP2:
-            l = lambda x: math.pow(2, x)
-        elif linearization == self.L_1_X:
-            l = lambda x: 1.0 / x
-        elif linearization == self.L_SQR:
-            l = lambda x: math.pow(x, 2)
-        elif linearization == self.L_CUBE:
-            l = lambda x: math.pow(x, 3)
-        elif linearization == self.L_SQRT:
-            l = math.sqrt
-        elif linearization == self.L_CUBERT:
-            l = lambda x: math.pow(x, 1.0/3)
-        elif linearization == self.L_LINEAR:
-            l = lambda x: x
-        else:
+        try:
+            return {
+                L_LN:     math.log,
+                L_LOG:    lambda x: math.log(x, 10),
+                L_LOG2:   lambda x: math.log(x, 2),
+                L_E:      math.exp,
+                L_EXP10:  lambda x: math.pow(10, x),
+                L_EXP2:   lambda x: math.pow(2, x),
+                L_1_X:    lambda x: 1.0 / x,
+                L_SQR:    lambda x: math.pow(x, 2),
+                L_CUBE:   lambda x: math.pow(x, 3),
+                L_SQRT:   math.sqrt,
+                L_CUBERT: lambda x: math.pow(x, 1.0/3),
+                L_LINEAR: lambda x: x,
+            }[self.linearization & 0x7f]
+        except KeyError:
             raise errors.DecodingError('unknown linearization %d' %
-                    linearization)
-        return l
+                    (self.linearization & 0x7f))
 
     def _convert_complement(self, value, size):
         if (value & (1 << (size-1))):
@@ -324,12 +297,9 @@ class SdrFullSensorRecord(SdrCommon):
     def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
         # record key bytes
-        self.owner_id = buffer.pop_unsigned_int(1)
-        self.owner_lun = buffer.pop_unsigned_int(1) & 0x3
-        self.number = buffer.pop_unsigned_int(1)
+        self._common_record_key(buffer.pop_slice(3))
         # record body bytes
-        self.entity_id = buffer.pop_unsigned_int(1)
-        self.entity_instance = buffer.pop_unsigned_int(1)
+        self._entity(buffer.pop_slice(2))
 
         # byte 11
         initialization = buffer.pop_unsigned_int(1)
@@ -467,25 +437,22 @@ class SdrFullSensorRecord(SdrCommon):
         self.reserved = buffer.pop_unsigned_int(2)
         self.oem = buffer.pop_unsigned_int(1)
         self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = buffer.to_string()
+        self.device_id_string = buffer.tostring()
 
 
 ###
 # SDR type 0x02
 ##################################################
 class SdrCompactSensorRecord(SdrCommon):
-    def __init__(self, data, next_id=None):
-        SdrCommon.__init__(self, data, next_id)
-        if data:
-            self._from_data(data)
-
     def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
-        self.owner_id = buffer.pop_unsigned_int(1)
-        self.owner_lun = buffer.pop_unsigned_int(1) & 0x3
-        self.number = buffer.pop_unsigned_int(1)
-        self.entity_id = buffer.pop_unsigned_int(1)
-        self.entity_instance = buffer.pop_unsigned_int(1)
+
+        # record key bytes
+        self._common_record_key(buffer.pop_slice(3))
+
+        # record body bytes
+        self._entity(buffer.pop_slice(2))
+
         self.sensor_initialization = buffer.pop_unsigned_int(1)
         self.capabilities = buffer.pop_unsigned_int(1)
         self.sensor_type_code = buffer.pop_unsigned_int(1)
@@ -502,69 +469,54 @@ class SdrCompactSensorRecord(SdrCommon):
         self.reserved = buffer.pop_unsigned_int(3)
         self.oem = buffer.pop_unsigned_int(1)
         self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = buffer.to_string()
+        self.device_id_string = buffer.tostring()
 
 
 ###
 # SDR type 0x03
 ##################################################
 class SdrEventOnlySensorRecord(SdrCommon):
-    def __init__(self, data, next_id=None):
-        SdrCommon.__init__(self, data, next_id)
-        if data:
-            self._from_data(data)
-
     def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
-        self.owner_id = buffer.pop_unsigned_int(1)
-        self.owner_lun = buffer.pop_unsigned_int(1) & 0x3
-        self.number = buffer.pop_unsigned_int(1)
-        self.entity_id = buffer.pop_unsigned_int(1)
-        self.entity_instance = buffer.pop_unsigned_int(1)
+
+        # record key bytes
+        self._common_record_key(buffer.pop_slice(3))
+
+        # record body bytes
+        self._entity(buffer.pop_slice(2))
+
         self.sensor_type = buffer.pop_unsigned_int(1)
         self.event_reading_type_code = buffer.pop_unsigned_int(1)
         self.record_sharing = buffer.pop_unsigned_int(2)
         self.reserved = buffer.pop_unsigned_int(1)
         self.oem = buffer.pop_unsigned_int(1)
         self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = buffer.to_string()
+        self.device_id_string = buffer.tostring()
+
 
 ###
 # SDR type 0x11
 ##################################################
 class SdrFruDeviceLocator(SdrCommon):
-    def __init__(self, data, next_id=None):
-        SdrCommon.__init__(self, data, next_id)
-        if data:
-            self._from_data(data)
-
     def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
-        # record key bytes
         self.device_access_address = buffer.pop_unsigned_int(1) >> 1
         self.fru_device_id = buffer.pop_unsigned_int(1)
         self.logical_physical = buffer.pop_unsigned_int(1)
         self.channel_number = buffer.pop_unsigned_int(1)
-        # record body bytes
         self.reserved = buffer.pop_unsigned_int(1)
         self.device_type = buffer.pop_unsigned_int(1)
         self.device_type_modifier= buffer.pop_unsigned_int(1)
-        self.entity_id = buffer.pop_unsigned_int(1)
-        self.entity_instance = buffer.pop_unsigned_int(1)
+        self._entity(buffer.pop_slice(2))
         self.oem = buffer.pop_unsigned_int(1)
         self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = buffer.to_string()
+        self.device_id_string = buffer.tostring()
 
 
 ###
 # SDR type 0x12
 ##################################################
 class SdrManagementContollerDeviceLocator(SdrCommon):
-    def __init__(self, data, next_id=None):
-        SdrCommon.__init__(self, data, next_id)
-        if data:
-            self._from_data(data)
-
     def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
         self.device_slave_address = buffer.pop_unsigned_int(1) >> 1
@@ -573,8 +525,7 @@ class SdrManagementContollerDeviceLocator(SdrCommon):
         self.global_initialization = 0
         self.device_capabilities = buffer.pop_unsigned_int(1)
         self.reserved = buffer.pop_unsigned_int(3)
-        self.entity_id = buffer.pop_unsigned_int(1)
-        self.entity_instance = buffer.pop_unsigned_int(1)
+        self._entity(buffer.pop_slice(2))
         self.oem = buffer.pop_unsigned_int(1)
         self.device_id_string_type_length = buffer.pop_unsigned_int(1)
-        self.device_id_string = buffer.to_string()
+        self.device_id_string = buffer.tostring()
