@@ -36,11 +36,8 @@ class Sel(object):
         return rsp.reservation_id
 
     def _clear_sel(self, cmd, reservation):
-        req = create_request_by_name('ClearSel')
-        req.reservation_id = reservation
-        req.cmd = cmd
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        rsp = self.send_message_with_name('ClearSel',
+                reservation_id=reservation, cmd=cmd)
         return rsp.status.erase_in_progress
 
     def clear_sel(self, retry=5):
@@ -49,9 +46,7 @@ class Sel(object):
 
     def sel_entries(self):
         """Generator which returns all SEL entries."""
-        req = create_request_by_name('GetSelInfo')
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        rsp = self.send_message_with_name('GetSelInfo')
         if rsp.entries == 0:
             return
         reservation_id = self.get_sel_reservation_id()
@@ -80,7 +75,7 @@ class Sel(object):
                 else:
                     check_completion_code(rsp.completion_code)
 
-                record_data.append_array(rsp.record_data)
+                record_data.extend(rsp.record_data)
                 req.offset = len(record_data)
 
                 if len(record_data) >= 16:
@@ -106,15 +101,15 @@ class SelInfo(State):
         self.most_recent_erase = rsp.most_recent_erase
         self.operation_support = []
         if rsp.operation_support.get_sel_allocation_info:
-           operation_support.append('get_sel_allocation_info')
+           self.operation_support.append('get_sel_allocation_info')
         if rsp.operation_support.reserve_sel:
-           operation_support.append('reserve_sel:')
+           self.operation_support.append('reserve_sel:')
         if rsp.operation_support.partial_add_sel_entry:
-           operation_support.append('partial_add_sel_entry')
+           self.operation_support.append('partial_add_sel_entry')
         if rsp.operation_support.delete_sel:
-           operation_support.append('delete_sel')
+           self.operation_support.append('delete_sel')
         if rsp.operation_support.overflow_flag:
-           operation_support.append('overflow_flag')
+           self.operation_support.append('overflow_flag')
 
 class SelEntry(State):
     TYPE_SYSTEM_EVENT = 0x02
